Crate stratum

Crate stratum 

Structs

Actor
A git actor who exists for the inspected repository
Commit
A singular git commit for the repository being inspected
GitUrl
A thin wrapper around git_url_parse::GitUrl.
Local
Unit struct indicating that a repository is local to the file system
ModifiedFile
A file that was touched in a commit
Remote
Unit struct indicating that a repository is remote to the file system
Repository
A Git Repository which can be mined.

Enums

Error

Functions

clone_repository
Helper function for cloning a remote repository given a url
open_repository
Helper function for opening a local repository given a path P