Actor

Struct Actor 

pub struct Actor { /* private fields */ }
A git actor who exists for the inspected repository

Implementations

Source

impl Actor

pub fn new(signature: Signature<'_>) -> Self

Instantiate a new Actor from their signature

pub fn name(&self) -> Option<String>

Return the actors name if it exists

pub fn email(&self) -> Option<String>

Return the actors email if it exists

pub fn timestamp(&self) -> Option<DateTime<Utc>>

Return the timestamp of actor action if it exists