Commit

Struct Commit 

pub struct Commit<'repo> { /* private fields */ }
A singular git commit for the repository being inspected

Implementations

Source

impl<'repo> Commit<'repo>

pub fn new(commit: Commit<'repo>, repository: &'repo Repository) -> Self

Instantiate a new Commit object from a git2 commit

pub fn hash(&self) -> String

Return the commit hash

pub fn msg(&self) -> Option<&str>

Return the commit message if it exists

pub fn author(&self) -> Actor

Return the commit author

pub fn co_authors(&self) -> impl Iterator<Item = Result<Actor, Error>>

Return the co-authors as listed in the commit message

Lazilly returning as an iterator means the co-authors, if entered more than once, will not be de-duplicated.

pub fn committer(&self) -> Actor

Return the commit committer

pub fn branches( &self, ) -> Result<impl Iterator<Item = Result<String, Error>>, Error>

Iterate all utf-8 branch names that the current commit is contained in

Note

Potentially expensive method. Take caution when using within a loop.

pub fn local_branches( &self, ) -> Result<impl Iterator<Item = Result<String, Error>>, Error>

Iterate all local utf-8 branch names that the current commit is contained in

Note

Potentially expensive method. Take caution when using within a loop.

pub fn remote_branches( &self, ) -> Result<impl Iterator<Item = Result<String, Error>>, Error>

Iterate all remote utf-8 branch names that the current commit is contained in

Note

Potentially expensive method. Take caution when using within a loop.

pub fn parents(&self) -> impl Iterator<Item = String>

Retrun the hashes of all commit parents

pub fn is_merge(&self) -> bool

Return whether the commit is a merge commit

pub fn in_main(&self) -> Result<bool, Error>

Checks if the current commit is reachable from “main” or “master”

pub fn mod_files(&self) -> Result<impl Iterator<Item = ModifiedFile<'_>>, Error>

Return an iterator over the modified files that belong to a commit

pub fn insertions(&self) -> Result<usize, Error>

The number of insertions in the commit

pub fn deletions(&self) -> Result<usize, Error>

The number of deletions in the commit

pub fn lines(&self) -> Result<usize, Error>

The total number of lines modified in the commit

pub fn files(&self) -> Result<usize, Error>

The number of files modified in the commit