ModifiedFile

Struct ModifiedFile 

pub struct ModifiedFile<'c> { /* private fields */ }
A file that was touched in a commit

Implementations

Source

impl<'c> ModifiedFile<'c>

pub fn new(diff: &'c Diff<'_>, n: usize) -> Self

Instantiate the modified file object from a git diff.

As a single diff can have > 1 modified/touched file, a single unsigned integer is provided to specify the delta and/or patch that this file looks to represent. Hence, the struct will normally be instantiated via iterating over the diff deltas as they are readily avaliable.

pub fn old_path(&self) -> Option<&Path>

Return the path of the old file in the diff

pub fn new_file(&self) -> Option<&Path>

Return the path of the new file in the diff

pub fn status(&self) -> Option<Delta>

Return the file status of the given patch