pub struct Commit<'repo> { /* private fields */ }Expand description
A singular git commit for the repository being inspected
Implementations
Sourceimpl<'repo> Commit<'repo>
impl<'repo> Commit<'repo>
Sourcepub fn new(commit: Commit<'repo>, repository: &'repo Repository) -> Self
pub fn new(commit: Commit<'repo>, repository: &'repo Repository) -> Self
Instantiate a new Commit object from a git2 commit
Return the commit author
Sourcepub fn mod_files(&self) -> Result<impl Iterator<Item = ModifiedFile<'_>>, Error>
pub fn mod_files(&self) -> Result<impl Iterator<Item = ModifiedFile<'_>>, Error>
Return an iterator over the modified files that belong to a commit
Sourcepub fn insertions(&self) -> Result<usize, Error>
pub fn insertions(&self) -> Result<usize, Error>
The number of insertions in the commit