GitUrl

Struct GitUrl 

pub struct GitUrl { /* private fields */ }
A thin wrapper around git_url_parse::GitUrl.

Designed to implement only what is needed within git-stratum and to preserve the original url string parsed as it is not traditionally preserved.

Implementations

Source

impl GitUrl

pub fn parse(s: &str) -> Result<Self, Error>

Parse the input string into a URL || Error

pub fn raw(&self) -> &str

Return the input URL string

pub fn scheme(&self) -> Option<&str>

Return the URL scheme

pub fn path(&self) -> &str

Return the URL path

pub fn split_path(&self) -> Split<'_, char>

Split the path on the delimeter ‘/’