pub struct GitUrl { /* private fields */ }Expand description
A thin wrapper around git_url_parse::GitUrl.
Designed to implement only what is needed within git-stratum and to preserve the original url string parsed as it is not traditionally preserved.
Implementations