Repository

Struct Repository 

pub struct Repository<Location = Local> { /* private fields */ }
A Git Repository which can be mined.

Two marker variations Local and Remote. Local is the variant which exists on the local filesystem and can therefore be mined. Remote, is of course not on the local filesystem and is represented via its remote url. A remote Repository upon instantiation will be cloned and returned as a Local variant such that it can be mined.

Examples

  1. Traversing a local repository from HEAD
use stratum::{Repository, Local};

let p = PathBuf::from_str("~/repository/").unwrap();
let repo = Repository::<Local>::new(p).unwrap();

for commit in repo.traverse_commits().unwrap() {
    let commit = commit.unwrap();
    println!("Commit {} was authored by {:?}", commit.hash(), commit.author().name());
}
  1. Traversing a remote repository from HEAD
use stratum::{Repository, Remote};

let repo = Repository::<Remote>::new::<PathBuf>(
        "https://server.example/owner/repo.git",
        None
    ).unwrap();
for commit in repo.traverse_commits().unwrap() {
    let commit = commit.unwrap();
    println!("Commit {} was authored by {:?}", commit.hash(), commit.author().name());
}
  1. Extracting HEAD from a local repository
use stratum::{Repository, Local};

let p = PathBuf::from_str("~/repository/").unwrap();
let repo = Repository::<Local>::new(p).unwrap();

println!("HEAD was authored by {:?}", repo.head().unwrap().author().name());
  1. Using the helper functions
use stratum::open_repository;

let p = PathBuf::from_str("~/repository/").unwrap();
// use clone_repository for the remote helper fucntion
let repo = open_repository(p);

println!("HEAD was authored by {:?}", repo.unwrap().head().unwrap().author().name());

Implementations

Source

impl Repository<Local>

pub fn new<P>(path: P) -> Result<Self, Error>
where P: AsRef<Path>,

Instatiate a new Repository from a path on the local file system

pub fn raw(&self) -> &Repository

Read access into the underlying git2 object

pub fn traverse_commits( &self, ) -> Result<impl Iterator<Item = Result<Commit<'_>, Error>>, Error>

Traverse the repositories commit graph from HEAD

pub fn traverse_from( &self, oid: &str, ) -> Result<impl Iterator<Item = Result<Commit<'_>, Error>>, Error>

Traverse the repositories commit graph from a specified commit hash

pub fn head(&self) -> Result<Commit<'_>, Error>

Return head as a stratum commit

pub fn single(&self, oid: &str) -> Result<Commit<'_>, Error>

Return a single commit object based on a given oid/hash

Source

impl Repository<Remote>

pub fn new<P>(url: &str, dest: Option<P>) -> Result<Repository<Local>, Error>
where P: AsRef<Path>,

Instatiate a new Repository from a remote URL, returning the Local variant after cloning the repository into dest.

Type of clone to perform will be automatically resolved based on the URL.

pub fn from_https<P>( url: &str, dest: Option<P>, ) -> Result<Repository<Local>, Error>
where P: AsRef<Path>,

Clone the given repository via the http or https protocol into the given destination

pub fn from_ssh<P>( _url: &str, _dest: Option<P>, ) -> Result<Repository<Local>, Error>
where P: AsRef<Path>,